export interface IglobalLogOptions {
    dirPath?: string;
    disabledTags?: Array<string | null>;
    filePrefix?: string;
    maxMsgLength?: number;
    printColor?: string;
    printConsole?: boolean;
}
/**
 * Returns a string that is formatted for logging.
 * @param {any} msg - A message to be logged.
 * @param {Date} date - Datetime of the log.
 * @param {string} tag - A tag of the log, if any.
 * @param {IglobalLogOptions} options - Custom options, if any.
 */
export declare const getLogStr: (msg: any, date: Date, tag?: string, options?: IglobalLogOptions) => string;
/**
 * Prints out a message.
 * @param {any} msg - The message text.
 * @param {string} tag - Tag to be used, if any.
 * @param {IglobalLogOptions} options - Custom options, if any.
 * @param {Date} date - Date, if any.
 */
export declare const print: (msg: any, tag?: string, options?: IglobalLogOptions, date?: Date) => void;
/**
 * Creates a log.
 * @param {string} msg - A message to log and print.
 * @param {string} tag - A tag for the message.
 * @param {boolean} doPrint - Whether to print console.log.
 * @param {object} options - Custom options for the execution.
 */
export declare const log: (msg: string, tag: string, doPrint: boolean, options: IglobalLogOptions) => void;
/**
 * Creates a log (synchronized).
 * @param {string} msg - A message to log and print.
 * @param {string} tag - A tag for the message.
 * @param {boolean} doPrint - Whether to print console.log.
 * @param {object} options - Custom options for the execution.
 */
export declare const logSync: (msg: string, tag: string, doPrint: boolean, options: IglobalLogOptions) => void;
/**
 * Returns the currently active
 * global log options.
 * @returns {object} - The current global log options.
 */
export declare const getGlobalLogOptions: () => IglobalLogOptions;
/**
 * Overrides either some or all of the global log options.
 * @param {object} options - New custom global log options.
 * @returns {object} - The current global log options after the modification.
 */
export declare const setGlobalLogOptions: (options: IglobalLogOptions) => IglobalLogOptions;
export declare const testUtil: () => any;
export default log;
